//
//  PartialFormatter.m
//  FilteringFieldTest
//
//  Created by Scott Gruby on 3/30/08.
//  Copyright 2008 GGT Enterprises, LLC. All rights reserved.
//

#import "PartialFormatter.h"


@implementation PartialFormatter
- (void) dealloc
{
	[filterCharacterSet release];
	[super dealloc];
}

- (BOOL)isPartialStringValid:(NSString *)partialString newEditingString:(NSString **)newString errorDescription:(NSString **)error
{
	if (filterCharacterSet != nil)
	{
		int i = 0;
		int len = [partialString length];
		for (i = 0; i < len; i++)
		{
			if (![filterCharacterSet characterIsMember:[partialString characterAtIndex:i]])
			{
				return NO;
			}
		}
	}

	if (maxLength)
	{
		if ([partialString length] > maxLength)
		{
			return NO;
		}
	}

	if (maxValue && [partialString intValue] > maxValue)
	{
		return NO;
	}
	
	return YES;
}

- (void) setAcceptableCharacterSet:(NSCharacterSet *) inCharacterSet
{
	[inCharacterSet retain];
	[filterCharacterSet release];
	filterCharacterSet = inCharacterSet;
}

- (void) setMaximumLength:(int) inLength
{
	maxLength = inLength;
}

- (void) setMaximumValue:(int) inValue
{
	maxValue = inValue;
}

- (NSString *)stringForObjectValue:(id)anObject
{
	if ([anObject isKindOfClass:[NSString class]])
	{
		return anObject;
	}
	
	return nil;
}

- (BOOL)getObjectValue:(id *)anObject forString:(NSString *)string errorDescription:(NSString **)error
{
	if (anObject && string)
	{
		*anObject = [NSString stringWithString:string];
	}
	
	return YES;
}
@end
